==> jest-coverage-to-csv-0.0.1.tgz: package/lib/index.js <==
#!/usr/bin/env node
"use strict";

var _yargs = require("yargs");

var _path = require("path");

var _fs = _interopRequireDefault(require("fs"));

var _helpers = require("./helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const {
  argv
} = (0, _yargs.usage)('Convert jest coverage report from coverage-summary to csv\nUsage: jest-coverage-to-csv [source] [target] [options]').wrap(null).example('jest-coverage-to-csv').example('jest-coverage-to-csv coverage/coverage-summary.json coverage/coverage-summary.csv').example('yarn test --coverage --coverageReporters=json-summary && jest-coverage-to-csv').options('so', {
  alias: 'statement-only',
  demandOption: false,
  default: false,
  describe: 'Print statement only instead of all summary',
  type: 'boolean'
}).options('po', {
  alias: 'percentage-only',
  demandOption: false,
  default: false,
  describe: 'Print percentage only instead of all details',
  type: 'boolean'
}).help().alias('help', 'h').version().alias('version', 'v');

try {
  const source = argv._[0] || './coverage/coverage-summary.json';
  let target = argv._[1] || './coverage/coverage-summary.csv';

  if ((0, _helpers.getExt)(source) !== 'json') {
    throw new Error('The source must be a JSON file.');
  }

  if ((0, _helpers.isFile)(target)) {
    target = (0, _path.resolve)(process.cwd(), target);
  }

  const coverageFile = _fs.default.readFileSync(source);

  const coverageJson = JSON.parse(coverageFile);
  let coverageCsv = '';

  if (argv.so) {
    if (argv.po) {
      coverageCsv += 'Filename, % Statements\n';
    } else {
      coverageCsv += 'Filename, % Statements, Statements\n';
    }
  } else if (argv.po) {
    coverageCsv += 'Filename, % Statements, % Branches, % Functions, % Lines\n';
  } else {
    coverageCsv += 'Filename, % Statements, Statements, % Branches, Branches, % Functions, Functions, % Lines, Lines\n';
  }

  Object.entries(coverageJson).forEach(([key, val]) => {
    const filename = key.replace(/^total$/, 'All Files').replace(new RegExp(`^${process.cwd()}/`), '');
    const st = val.statements;
    const br = val.branches;
    const fn = val.functions;
    const ln = val.lines;

    if (argv.so) {
      if (argv.po) {
        coverageCsv += `${filename}, ${st.pct}\n`;
      } else {
        coverageCsv += `${filename}, ${st.pct}, ${st.covered}/${st.total}\n`;
      }
    } else if (argv.po) {
      coverageCsv += `${filename}, ${st.pct}, ${br.pct}, ${fn.pct}, ${ln.pct}\n`;
    } else {
      coverageCsv += `${filename}, ${st.pct}, ${st.covered}/${st.total}, ${br.pct}, ${br.covered}/${br.total}, ${fn.pct}, ${fn.covered}/${fn.total}, ${ln.pct}, ${ln.covered}/${ln.total}\n`;
    }
  });

  _fs.default.writeFileSync(target, coverageCsv, {
    recursive: true,
    flag: 'w'
  });

  console.log('Conversion to CSV success!');
} catch (err) {
  console.error(err.message || err);
}

==> jest-coverage-to-csv-0.0.4.tgz: package/lib/index.js <==
#!/usr/bin/env node
"use strict";

var _yargs = require("yargs");

var _path = require("path");

var _fs = _interopRequireDefault(require("fs"));

var _helpers = require("./helpers");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const {
  argv
} = (0, _yargs.usage)('Convert jest coverage report from coverage-summary to csv\nUsage: jest-coverage-to-csv [source] [target] [options]').wrap(null).example('jest-coverage-to-csv').example('jest-coverage-to-csv coverage/coverage-summary.json coverage/coverage-summary.csv').example('yarn test --coverage --coverageReporters=json-summary && jest-coverage-to-csv').options('so', {
  alias: 'statement-only',
  demandOption: false,
  default: false,
  describe: 'Print statement only instead of all summary',
  type: 'boolean'
}).options('po', {
  alias: 'percentage-only',
  demandOption: false,
  default: false,
  describe: 'Print percentage only instead of all details',
  type: 'boolean'
}).help().alias('help', 'h').version().alias('version', 'v');

try {
  const source = argv._[0] || './coverage/coverage-summary.json';
  let target = argv._[1] || './coverage/coverage-summary.csv';

  if ((0, _helpers.getExt)(source) !== 'json') {
    throw new Error('The source must be a JSON file.');
  }

  if ((0, _helpers.isFile)(target)) {
    target = (0, _path.resolve)(process.cwd(), target);
  }

  const coverageFile = _fs.default.readFileSync(source);

  const coverageJson = JSON.parse(coverageFile);
  let coverageCsv = [];

  if (argv.so) {
    if (argv.po) {
      coverageCsv.push('Filename, % Statements');
    } else {
      coverageCsv.push('Filename, % Statements, Statements');
    }
  } else if (argv.po) {
    coverageCsv.push('Filename, % Statements, % Branches, % Functions, % Lines');
  } else {
    coverageCsv.push('Filename, % Statements, Statements, % Branches, Branches, % Functions, Functions, % Lines, Lines');
  }

  Object.entries(coverageJson).forEach(([key, val]) => {
    const filename = key.replace(/^total$/, 'All Files').replace(new RegExp(`^${process.cwd()}/`), '');
    const st = val.statements;
    const br = val.branches;
    const fn = val.functions;
    const ln = val.lines;

    if (argv.so) {
      if (argv.po) {
        coverageCsv.push(`${filename}, ${st.pct}`);
      } else {
        coverageCsv.push(`${filename}, ${st.pct}, ${st.covered}/${st.total}`);
      }
    } else if (argv.po) {
      coverageCsv.push(`${filename}, ${st.pct}, ${br.pct}, ${fn.pct}, ${ln.pct}`);
    } else {
      coverageCsv.push(`${filename}, ${st.pct}, ${st.covered}/${st.total}, ${br.pct}, ${br.covered}/${br.total}, ${fn.pct}, ${fn.covered}/${fn.total}, ${ln.pct}, ${ln.covered}/${ln.total}`);
    }
  });
  coverageCsv = [...coverageCsv.slice(0, 2), ...coverageCsv.slice(2).sort((a, b) => a.localeCompare(b)), ''].join('\n');

  _fs.default.writeFileSync(target, coverageCsv, {
    recursive: true,
    flag: 'w'
  });

  console.log('Conversion to CSV success!');
} catch (err) {
  console.error(err.message || err);
}
